**Usage**

Run the command `robonav` to spin up a robot navigating on an open world. The available directions are up, down, left and right. The initial option allows you to recenter the robot on the specified coordinates.